==> dl.php?src=linea21_2_0_0.zip: linea21/languages/es/lang_workshoprep.utf-8.php <==
<?php
/**
 * @package linea21\languages\es
 * @author $Author$ - Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['workshoprep']['section'] = "informes de los grupos de trabajo";

/*	nommage des modules
 *  	*/
$lang['workshoprep']['name']='informe';
$lang['workshoprep']['confirm_add'] = "Informe añadido correctamente";
$lang['workshoprep']['confirm_mod'] = "Informe actualizado correctamente";
$lang['workshoprep']['confirm_sup'] ="Informe eliminado correctamente";


/*	nommage rubrique module
 *  	*/
$lang['workshoprep']['add']= 'Añadir nuevo '.$lang['workshoprep']['name'];
$lang['workshoprep']['mod']= 'Editar '.$lang['workshoprep']['name'];
$lang['workshoprep']['sup']= 'Eliminar '.$lang['workshoprep']['name'];
$lang['workshoprep']['det']= ucfirst($lang['workshoprep']['name']). ' detalles';
$lang['workshoprep']['return_workshop']= 'Volver al grupo de trabajo';


/*	public
 *  	*/
$lang['workshoprep']['name2']='detalles del informe';


/*	nommage rubrique add / mod /det
 *  	*/
$lang['workshoprep']['add_title']='Añadir valores al nuevo '.$lang['workshoprep']['name'];
$lang['workshoprep']['mod_title']='Editar valores del '.$lang['workshoprep']['name'];


/*	check integrité des données
 *  	*/
$lang['workshoprep']['no_title'] = 'El título es requerido.';
$lang['workshoprep']['no_resume'] = 'El resumen es requerido.';


/*	nommage élément rubrique
 *  	*/
$lang['workshoprep']['title']='título';
$lang['workshoprep']['resume']='resumen';
$lang['workshoprep']['workshop_product']='elaborado por el grupo';

$lang['workshoprep']['statut']='estado';
$lang['workshoprep']['comment']='comentarios';

$lang['workshoprep']['published_on']='publicado a fecha';
$lang['workshoprep']['not_published']='no publicado';

$lang['workshoprep']['generals']='información global';
$lang['workshoprep']['parts']='apartados';
$lang['workshoprep']['link_res']='enlaces';
$lang['workshoprep']['biblio_res']='fuentes bibliográficas';


/*	nommage quickbox
 *  	*/
$lang['workshoprep']['qb_titleadd']=' informes añadidos recientemente';
$lang['workshoprep']['qb_titlemod']=' informes modificados recientemente';
$lang['workshoprep']['qb_titlesup']=' informes eliminados recientemente';
$lang['workshoprep']['qb_titlepubli']=' últimas publicaciones';


/*	divers
 *  	*/
$lang['workshoprep']['description']='descripción';
$lang['workshoprep']['part_number']='apartado ';


/*	messages
 *  	*/
$lang['workshoprep']['add_new_part']="Añadir nuevo apartado";
$lang['workshoprep']['add_new_linkres']="Añadir nuevo enlace";
$lang['workshoprep']['add_new_bibliores']="Añadir nueva fuente bibliográfica";

$lang['workshoprep']['no_link']="No existe sitio web para este informe";
$lang['workshoprep']['del_link']="Eliminar enlace";
$lang['workshoprep']['mod_link']="Editar enlace";

$lang['workshoprep']['no_biblio']="No existen fuentes bibliográficas en este informe";
$lang['workshoprep']['del_biblio']="Eliminar fuente bibliográfica";
$lang['workshoprep']['mod_biblio']="Editar fuente bibliográfica";

$lang['workshoprep']['no_part']="No existen apartados en este informe";
$lang['workshoprep']['del_part']="Eliminar apartado";
$lang['workshoprep']['mod_part']="Editar apartado";






/*	rubrique d'aide

*  	*/
$lang['workshoprep']['help_add1']='Para añadir un nuevo informe, inserte la información requerida en el formulario.';
$lang['workshoprep']['help_add2']='Completado el formulario, revise los valores en el resumen.';
$lang['workshoprep']['help_add3']='Validado el resumen, haga click en "revisar valores" si desea realizar cambios.';

$lang['workshoprep']['help_mod1']='Para editar un informe, inserte la información requerida en el formulario.';
$lang['workshoprep']['help_mod2']='Completado el formulario, revise los valores en el resumen.';
$lang['workshoprep']['help_mod3']='Validado el resumen, haga click en "revisar valores" si desea realizar cambios.';


$lang['workshoprep']['help_det1']='Para editar un informe, haga click en el icono "editar informe".';
$lang['workshoprep']['help_det2']='Para eliminar un informe, haga click en el icono "eliminar informe".';
$lang['workshoprep']['help_det3']='Para más información haga click en el título del informe.';
$lang['workshoprep']['help_det4']='Haga click en los iconos asociados a añadir, eliminar o actualizar informe.';

$lang['workshoprep']['help_sup1']='Para abortar la eliminación, haga click en "cancelar".';


?>

==> dl.php?src=linea21_2_3_0.zip: linea21/languages/es/lang_workshoprep.utf-8.php <==
<?php
/**
 * @package linea21\languages\es
 * @author $Author$ - Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['workshoprep']['section'] = "informes de los grupos de trabajo";

/*	nommage des modules
 *  	*/
$lang['workshoprep']['name']='informe';
$lang['workshoprep']['confirm_add'] = "Informe añadido correctamente";
$lang['workshoprep']['confirm_mod'] = "Informe actualizado correctamente";
$lang['workshoprep']['confirm_sup'] ="Informe eliminado correctamente";


/*	nommage rubrique module
 *  	*/
$lang['workshoprep']['add']= 'Añadir nuevo '.$lang['workshoprep']['name'];
$lang['workshoprep']['mod']= 'Editar '.$lang['workshoprep']['name'];
$lang['workshoprep']['sup']= 'Eliminar '.$lang['workshoprep']['name'];
$lang['workshoprep']['det']= ucfirst($lang['workshoprep']['name']). ' detalles';
$lang['workshoprep']['return_workshop']= 'Volver al grupo de trabajo';


/*	public
 *  	*/
$lang['workshoprep']['name2']='detalles del informe';


/*	nommage rubrique add / mod /det
 *  	*/
$lang['workshoprep']['add_title']='Añadir valores al nuevo '.$lang['workshoprep']['name'];
$lang['workshoprep']['mod_title']='Editar valores del '.$lang['workshoprep']['name'];


/*	check integrité des données
 *  	*/
$lang['workshoprep']['no_title'] = 'El título es requerido.';
$lang['workshoprep']['no_resume'] = 'El resumen es requerido.';


/*	nommage élément rubrique
 *  	*/
$lang['workshoprep']['title']='título';
$lang['workshoprep']['resume']='resumen';
$lang['workshoprep']['workshop_product']='elaborado por el grupo';

$lang['workshoprep']['statut']='estado';
$lang['workshoprep']['comment']='comentarios';

$lang['workshoprep']['published_on']='publicado a fecha';
$lang['workshoprep']['not_published']='no publicado';

$lang['workshoprep']['generals']='información global';
$lang['workshoprep']['parts']='apartados';
$lang['workshoprep']['link_res']='enlaces';
$lang['workshoprep']['biblio_res']='fuentes bibliográficas';


/*	nommage quickbox
 *  	*/
$lang['workshoprep']['qb_titleadd']=' informes añadidos recientemente';
$lang['workshoprep']['qb_titlemod']=' informes modificados recientemente';
$lang['workshoprep']['qb_titlesup']=' informes eliminados recientemente';
$lang['workshoprep']['qb_titlepubli']=' últimas publicaciones';


/*	divers
 *  	*/
$lang['workshoprep']['description']='descripción';
$lang['workshoprep']['part_number']='apartado ';


/*	messages
 *  	*/
$lang['workshoprep']['add_new_part']="Añadir nuevo apartado";
$lang['workshoprep']['add_new_linkres']="Añadir nuevo enlace";
$lang['workshoprep']['add_new_bibliores']="Añadir nueva fuente bibliográfica";

$lang['workshoprep']['no_link']="No existe sitio web para este informe";
$lang['workshoprep']['del_link']="Eliminar enlace";
$lang['workshoprep']['mod_link']="Editar enlace";

$lang['workshoprep']['no_biblio']="No existen fuentes bibliográficas en este informe";
$lang['workshoprep']['del_biblio']="Eliminar fuente bibliográfica";
$lang['workshoprep']['mod_biblio']="Editar fuente bibliográfica";

$lang['workshoprep']['no_part']="No existen apartados en este informe";
$lang['workshoprep']['del_part']="Eliminar apartado";
$lang['workshoprep']['mod_part']="Editar apartado";






/*	rubrique d'aide

*  	*/
$lang['workshoprep']['help_add1']='Para añadir un nuevo informe, inserte la información requerida en el formulario.';
$lang['workshoprep']['help_add2']='Completado el formulario, revise los valores en el resumen.';
$lang['workshoprep']['help_add3']='Validado el resumen, haga clic en "revisar valores" si desea realizar cambios.';

$lang['workshoprep']['help_mod1']='Para editar un informe, inserte la información requerida en el formulario.';
$lang['workshoprep']['help_mod2']='Completado el formulario, revise los valores en el resumen.';
$lang['workshoprep']['help_mod3']='Validado el resumen, haga clic en "revisar valores" si desea realizar cambios.';


$lang['workshoprep']['help_det1']='Para editar un informe, haga clic en el icono "editar informe".';
$lang['workshoprep']['help_det2']='Para eliminar un informe, haga clic en el icono "eliminar informe".';
$lang['workshoprep']['help_det3']='Para más información haga clic en el título del informe.';
$lang['workshoprep']['help_det4']='Haga clic en los iconos asociados a añadir, eliminar o actualizar informe.';

$lang['workshoprep']['help_sup1']='Para abortar la eliminación, haga clic en "cancelar".';
?>
